searchData={"items":[{"type":"module","title":"UnionTypespec","doc":"A simple, tiny, compile time-only library for defining an Elixir `@type` whose values are one of a fixed set of options.","ref":"UnionTypespec.html"},{"type":"macro","title":"UnionTypespec.union_type/1","doc":"Transforms an enumerable (like a list of atoms) into an AST for use in a typespec.\n\nThis is primarily useful when you have a module attribute that defines\n\nTaken wholesale from [Eiji's ElixirForum answer](https://elixirforum.com/t/dynamically-generate-typespecs-from-module-attribute-list/7078/5).\n\nExample:\n\n    defmodule MyModule do\n      import UnionTypespec, only: [union_type: 1]\n\n      @permissions [:view, :edit, :admin]\n      union_type permission :: @permissions\n\n      @spec random_permission() :: permission()\n      def random_permission, do: Enum.random(@permissions)\n    end","ref":"UnionTypespec.html#union_type/1"},{"type":"function","title":"UnionTypespec.union_type_ast/1","doc":"Unquote on the right-hand side of `@type` if you prefer the explicitness of that syntax over the `union_type` macro.\n\nExample:\n\n    defmodule MyModule do\n      @permissions [:view, :edit, :admin]\n      @type permission :: unquote(UnionTypespec.union_type_ast(@permissions))\n\n      @spec random_permission() :: permission()\n      def random_permission, do: Enum.random(@permissions)\n    end","ref":"UnionTypespec.html#union_type_ast/1"},{"type":"macro","title":"UnionTypespec.union_typep/1","doc":"Same as `UnionTypespec.union_type/1` but for a private type (`@typep`).\n\nExample:\n\n    defmodule MyModule do\n      import UnionTypespec, only: [union_typep: 1]\n\n      @permissions [:view, :edit, :admin]\n      union_typep permission :: @permissions\n\n      @spec random_permission() :: permission()\n      defp random_permission, do: Enum.random(@permissions)\n    end","ref":"UnionTypespec.html#union_typep/1"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)\n\n## [0.0.3] - 2024-XX-XX","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- `UnionTypespec.union_typep/1` macro.","ref":"changelog.html#added"},{"type":"extras","title":"union_typespec","doc":"# union_typespec\n\nA simple, tiny, compile time-only library for defining an Elixir `@type` whose values\nare one of a fixed set of options.\n\nThere are two ways to use it:\n\n1. The `union_type` and `union_typep` macros, which replaces normal `@type`/`@typep` annotations with a nice,\n   concise macro version of the type definition.\n2. `UnionTypespec.union_type_ast/1`, which produces an AST you can `unquote` within\n   the usual `@type` definition.\n\nHere's what those look like in practice:\n\n```elixir\ndefmodule MyModule do\n  import UnionTypespec, only: [union_type: 1]\n\n  @statuses [:read, :unread, :deleted]\n  union_type status :: @statuses\n\n  @permissions [:view, :edit, :admin]\n  @type permission :: unquote(UnionTypespec.union_type_ast(@permissions))\n\n  @spec get_permission() :: permission()\n  def get_permission, do: Enum.random(@permissions)\n\n  @spec get_status() :: status()\n  def get_status, do: Enum.random(@statuses)\nend\n```","ref":"readme.html"},{"type":"extras","title":"Installation - union_typespec","doc":"You can install the package from Hex by adding this to your `mix.exs` file's dependencies:\n\n```elixir\ndef deps do\n  [\n    {:union_typespec, \"~> 0.0.4\", runtime: false},\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}